# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/faststream-gen',
                'doc_host': 'https://airtai.github.io',
                'git_url': 'https://github.com/airtai/faststream-gen',
                'lib_path': 'faststream_gen'},
  'syms': { 'faststream_gen._code_generator.app_and_test_generator': { 'faststream_gen._code_generator.app_and_test_generator._split_app_and_test_code': ( 'app_and_test_generator.html#_split_app_and_test_code',
                                                                                                                                                           'faststream_gen/_code_generator/app_and_test_generator.py'),
                                                                       'faststream_gen._code_generator.app_and_test_generator._validate_response': ( 'app_and_test_generator.html#_validate_response',
                                                                                                                                                     'faststream_gen/_code_generator/app_and_test_generator.py'),
                                                                       'faststream_gen._code_generator.app_and_test_generator.generate_app_and_test': ( 'app_and_test_generator.html#generate_app_and_test',
                                                                                                                                                        'faststream_gen/_code_generator/app_and_test_generator.py')},
            'faststream_gen._code_generator.app_description_validator': { 'faststream_gen._code_generator.app_description_validator.validate_app_description': ( 'app_description_validator.html#validate_app_description',
                                                                                                                                                                 'faststream_gen/_code_generator/app_description_validator.py')},
            'faststream_gen._code_generator.app_skeleton_generator': { 'faststream_gen._code_generator.app_skeleton_generator.generate_app_skeleton': ( 'app_skeleton_generator.html#generate_app_skeleton',
                                                                                                                                                        'faststream_gen/_code_generator/app_skeleton_generator.py')},
            'faststream_gen._code_generator.constants': { 'faststream_gen._code_generator.constants.OpenAIModel': ( 'constants.html#openaimodel',
                                                                                                                    'faststream_gen/_code_generator/constants.py')},
            'faststream_gen._code_generator.helper': { 'faststream_gen._code_generator.helper.CustomAIChat': ( 'helper.html#customaichat',
                                                                                                               'faststream_gen/_code_generator/helper.py'),
                                                       'faststream_gen._code_generator.helper.CustomAIChat.__call__': ( 'helper.html#customaichat.__call__',
                                                                                                                        'faststream_gen/_code_generator/helper.py'),
                                                       'faststream_gen._code_generator.helper.CustomAIChat.__init__': ( 'helper.html#customaichat.__init__',
                                                                                                                        'faststream_gen/_code_generator/helper.py'),
                                                       'faststream_gen._code_generator.helper.CustomAIChat._get_doc': ( 'helper.html#customaichat._get_doc',
                                                                                                                        'faststream_gen/_code_generator/helper.py'),
                                                       'faststream_gen._code_generator.helper.ValidateAndFixResponse': ( 'helper.html#validateandfixresponse',
                                                                                                                         'faststream_gen/_code_generator/helper.py'),
                                                       'faststream_gen._code_generator.helper.ValidateAndFixResponse.__init__': ( 'helper.html#validateandfixresponse.__init__',
                                                                                                                                  'faststream_gen/_code_generator/helper.py'),
                                                       'faststream_gen._code_generator.helper.ValidateAndFixResponse.construct_prompt_with_error_msg': ( 'helper.html#validateandfixresponse.construct_prompt_with_error_msg',
                                                                                                                                                         'faststream_gen/_code_generator/helper.py'),
                                                       'faststream_gen._code_generator.helper.ValidateAndFixResponse.fix': ( 'helper.html#validateandfixresponse.fix',
                                                                                                                             'faststream_gen/_code_generator/helper.py'),
                                                       'faststream_gen._code_generator.helper._fetch_content': ( 'helper.html#_fetch_content',
                                                                                                                 'faststream_gen/_code_generator/helper.py'),
                                                       'faststream_gen._code_generator.helper._format_examples': ( 'helper.html#_format_examples',
                                                                                                                   'faststream_gen/_code_generator/helper.py'),
                                                       'faststream_gen._code_generator.helper._get_relevant_document': ( 'helper.html#_get_relevant_document',
                                                                                                                         'faststream_gen/_code_generator/helper.py'),
                                                       'faststream_gen._code_generator.helper._retry_with_exponential_backoff': ( 'helper.html#_retry_with_exponential_backoff',
                                                                                                                                  'faststream_gen/_code_generator/helper.py'),
                                                       'faststream_gen._code_generator.helper._split_text': ( 'helper.html#_split_text',
                                                                                                              'faststream_gen/_code_generator/helper.py'),
                                                       'faststream_gen._code_generator.helper.add_tokens_usage': ( 'helper.html#add_tokens_usage',
                                                                                                                   'faststream_gen/_code_generator/helper.py'),
                                                       'faststream_gen._code_generator.helper.download_and_extract_faststream_archive': ( 'helper.html#download_and_extract_faststream_archive',
                                                                                                                                          'faststream_gen/_code_generator/helper.py'),
                                                       'faststream_gen._code_generator.helper.get_relevant_prompt_examples': ( 'helper.html#get_relevant_prompt_examples',
                                                                                                                               'faststream_gen/_code_generator/helper.py'),
                                                       'faststream_gen._code_generator.helper.read_file_contents': ( 'helper.html#read_file_contents',
                                                                                                                     'faststream_gen/_code_generator/helper.py'),
                                                       'faststream_gen._code_generator.helper.set_logger_level': ( 'helper.html#set_logger_level',
                                                                                                                   'faststream_gen/_code_generator/helper.py'),
                                                       'faststream_gen._code_generator.helper.validate_python_code': ( 'helper.html#validate_python_code',
                                                                                                                       'faststream_gen/_code_generator/helper.py'),
                                                       'faststream_gen._code_generator.helper.write_file_contents': ( 'helper.html#write_file_contents',
                                                                                                                      'faststream_gen/_code_generator/helper.py')},
            'faststream_gen._code_generator.prompts': {},
            'faststream_gen._components.embeddings': { 'faststream_gen._components.embeddings._append_file_contents': ( 'embeddings_cli.html#_append_file_contents',
                                                                                                                        'faststream_gen/_components/embeddings.py'),
                                                       'faststream_gen._components.embeddings._check_all_files_exist': ( 'embeddings_cli.html#_check_all_files_exist',
                                                                                                                         'faststream_gen/_components/embeddings.py'),
                                                       'faststream_gen._components.embeddings._create_documents': ( 'embeddings_cli.html#_create_documents',
                                                                                                                    'faststream_gen/_components/embeddings.py'),
                                                       'faststream_gen._components.embeddings._delete_directory': ( 'embeddings_cli.html#_delete_directory',
                                                                                                                    'faststream_gen/_components/embeddings.py'),
                                                       'faststream_gen._components.embeddings._format_examples': ( 'embeddings_cli.html#_format_examples',
                                                                                                                   'faststream_gen/_components/embeddings.py'),
                                                       'faststream_gen._components.embeddings._generate_docs_db': ( 'embeddings_cli.html#_generate_docs_db',
                                                                                                                    'faststream_gen/_components/embeddings.py'),
                                                       'faststream_gen._components.embeddings._generate_examples_db': ( 'embeddings_cli.html#_generate_examples_db',
                                                                                                                        'faststream_gen/_components/embeddings.py'),
                                                       'faststream_gen._components.embeddings._save_embeddings_db': ( 'embeddings_cli.html#_save_embeddings_db',
                                                                                                                      'faststream_gen/_components/embeddings.py'),
                                                       'faststream_gen._components.embeddings._split_document_into_chunks': ( 'embeddings_cli.html#_split_document_into_chunks',
                                                                                                                              'faststream_gen/_components/embeddings.py'),
                                                       'faststream_gen._components.embeddings.generate': ( 'embeddings_cli.html#generate',
                                                                                                           'faststream_gen/_components/embeddings.py')},
            'faststream_gen._components.logger': { 'faststream_gen._components.logger.get_default_logger_configuration': ( 'logger.html#get_default_logger_configuration',
                                                                                                                           'faststream_gen/_components/logger.py'),
                                                   'faststream_gen._components.logger.get_logger': ( 'logger.html#get_logger',
                                                                                                     'faststream_gen/_components/logger.py'),
                                                   'faststream_gen._components.logger.set_level': ( 'logger.html#set_level',
                                                                                                    'faststream_gen/_components/logger.py'),
                                                   'faststream_gen._components.logger.suppress_timestamps': ( 'logger.html#suppress_timestamps',
                                                                                                              'faststream_gen/_components/logger.py')},
            'faststream_gen._components.new_project_generator': { 'faststream_gen._components.new_project_generator._generate_requirements': ( 'new_project_generator.html#_generate_requirements',
                                                                                                                                               'faststream_gen/_components/new_project_generator.py'),
                                                                  'faststream_gen._components.new_project_generator._split_requirements': ( 'new_project_generator.html#_split_requirements',
                                                                                                                                            'faststream_gen/_components/new_project_generator.py'),
                                                                  'faststream_gen._components.new_project_generator._validate_response': ( 'new_project_generator.html#_validate_response',
                                                                                                                                           'faststream_gen/_components/new_project_generator.py'),
                                                                  'faststream_gen._components.new_project_generator.create_project': ( 'new_project_generator.html#create_project',
                                                                                                                                       'faststream_gen/_components/new_project_generator.py')},
            'faststream_gen._components.package_data': { 'faststream_gen._components.package_data.get_root_data_path': ( 'packagedata.html#get_root_data_path',
                                                                                                                         'faststream_gen/_components/package_data.py')},
            'faststream_gen.cli': { 'faststream_gen.cli._calculate_price': ('cli.html#_calculate_price', 'faststream_gen/cli.py'),
                                    'faststream_gen.cli._ensure_openai_api_key_set': ( 'cli.html#_ensure_openai_api_key_set',
                                                                                       'faststream_gen/cli.py'),
                                    'faststream_gen.cli._get_description': ('cli.html#_get_description', 'faststream_gen/cli.py'),
                                    'faststream_gen.cli._strip_white_spaces': ('cli.html#_strip_white_spaces', 'faststream_gen/cli.py'),
                                    'faststream_gen.cli.generate_fastkafka_app': ( 'cli.html#generate_fastkafka_app',
                                                                                   'faststream_gen/cli.py')}}}
